@@ -393,7 +393,7 @@ error:
 	return NULL;
 }
 
-void smlDsSessionRef(SmlDsSession *dsession)
+SmlDsSession *smlDsSessionRef(SmlDsSession *dsession)
 {
 	smlTrace(TRACE_ENTRY, "%s(%p)", __func__, dsession);
 	smlAssert(dsession);
@@ -401,6 +401,7 @@ void smlDsSessionRef(SmlDsSession *dsession)
 	g_atomic_int_inc(&(dsession->refCount));
 	
 	smlTrace(TRACE_EXIT, "%s: New refcount: %i", __func__, dsession->refCount);
+	return dsession;
 }
 
 void smlDsSessionUnref(SmlDsSession *dsession)
@@ -461,10 +462,11 @@ void smlDsSessionDispatch(SmlDsSession *dsession)
 	SmlError *error = NULL;
 	SmlStatus *reply = NULL;
 	
+	g_mutex_lock(dsession->lock);
+
 	if (dsession->alertCommand && dsession->recvAlertCallback) {
 		smlTrace(TRACE_ENTRY, "%s(%p): Dispatching alert", __func__, dsession);
 		
-		g_mutex_lock(dsession->lock);
 		SmlErrorType type = SML_NO_ERROR;
 		if (!dsession->recvAlertCallback(dsession, dsession->alertCommand->private.alert.type, dsession->alertCommand->private.alert.anchor->last, dsession->alertCommand->private.alert.anchor->next, dsession->recvAlertCallbackUserdata))
 			type = SML_ERROR_REQUIRE_REFRESH;
@@ -483,13 +485,11 @@ void smlDsSessionDispatch(SmlDsSession *dsession)
 		smlCommandUnref(dsession->alertCommand);
 		dsession->alertCommand = NULL;
 
-		g_mutex_unlock(dsession->lock);
 		smlTrace(TRACE_EXIT, "%s", __func__);
 	} else if (dsession->recvSync && dsession->recvSyncCallback) {
 		smlTrace(TRACE_ENTRY, "%s(%p): Dispatching sync", __func__, dsession);
 		
-		g_mutex_lock(dsession->lock);
-		dsession->recvSyncCallback(dsession, ((SmlCommand *)(dsession->recvSync->data))->private.sync.numChanged, dsession->changesCallbackUserdata);
+		dsession->recvSyncCallback(dsession, ((SmlCommand *)(dsession->recvSync->data))->private.sync.numChanged, dsession->recvSyncCallbackUserdata);
 		dsession->recvSyncCallback = NULL;
 		
 		while (dsession->recvSync) {
@@ -511,13 +511,18 @@ void smlDsSessionDispatch(SmlDsSession *dsession)
 		
 		dsession->syncReply = SML_NO_ERROR;
 		
-		g_mutex_unlock(dsession->lock);
+		// Now there are no more changes... do some fancy callback. Some applications will love it ;)
+		if (!dsession->recvChanges && dsession->recvEventCallback) {
+			dsession->recvEventCallback(dsession, SML_DS_EVENT_GOTCHANGES, dsession->recvEventCallbackUserdata);
+			smlTrace(TRACE_INTERNAL, "recvEventCallback no changes in recvSync callback");
+		}
+
 		smlTrace(TRACE_EXIT, "%s", __func__);
 	} else if (dsession->recvChanges && dsession->changesCallback) {
 		smlTrace(TRACE_ENTRY, "%s(%p): Dispatching changes", __func__, dsession);
 		
-		g_mutex_lock(dsession->lock);
 		while (dsession->recvChanges) {
+
 			SmlCommand *cmd = dsession->recvChanges->data;
 			
 			if (cmd) {
@@ -530,7 +535,7 @@ void smlDsSessionDispatch(SmlDsSession *dsession)
 				/* We'd rather use the target of the change since it already the mapped
 				 * uid (if we are a client for example). If it is not given we use the
 				 * source uri. This has then to be translated by the sync engine of course */
-				
+
 				char *data = NULL;
 				unsigned int size = 0;
 				if (!smlItemStealData(item, &data, &size, &error))
@@ -558,10 +563,24 @@ void smlDsSessionDispatch(SmlDsSession *dsession)
 			
 			dsession->recvChanges = g_list_delete_link(dsession->recvChanges, dsession->recvChanges);
 		}
-		g_mutex_unlock(dsession->lock);
-		
+
+		// Now there are no more changes... do some fancy callback. Some applications will love it ;)
+		if (dsession->recvEventCallback) {
+			dsession->recvEventCallback(dsession, SML_DS_EVENT_GOTCHANGES, dsession->recvEventCallbackUserdata);
+			smlTrace(TRACE_INTERNAL, "recvEventCallback all changes sent in recvChanges callback");
+		}
+
 		smlTrace(TRACE_EXIT, "%s", __func__);
+	} else {
+		smlTrace(TRACE_ENTRY, "%s()", __func__);
+		
+		smlTrace(TRACE_INTERNAL, "recvChanges: %p changesCallback: %p", dsession->recvChanges, dsession->changesCallback); 
+
+		smlTrace(TRACE_EXIT, "%s()", __func__);
+
 	}
+
+	g_mutex_unlock(dsession->lock);
 	
 	return;
 
@@ -832,6 +851,21 @@ void smlDsSessionGetSync(SmlDsSession *dsession, SmlDsSessionSyncCb syncCallback
 	smlTrace(TRACE_EXIT, "%s", __func__);
 }
 
+void smlDsSessionGetEvent(SmlDsSession *dsession, SmlDsSessionEventCb eventCallback, void *userdata)
+{
+	smlTrace(TRACE_ENTRY, "%s(%p, %p, %p)", __func__, dsession, eventCallback, userdata);
+	smlAssert(dsession);
+	smlAssert(eventCallback);
+	
+	dsession->recvEventCallback = eventCallback;
+	dsession->recvEventCallbackUserdata = userdata;
+	
+	//smlDsSessionDispatch(dsession);
+	
+	smlTrace(TRACE_EXIT, "%s", __func__);
+}
+
+
 /** @brief Start the sync command to send to the other side
  * 
  * This function will start the sync command with which the changes will be sent to the other side.
