@@ -1441,14 +1441,17 @@ SmlBool smlXmlAssemblerRunFull(SmlXmlAssembler *assm, char **data, unsigned int
 	/* Add the syncml start node */
 	switch (assm->session->version) {
 		case SML_VERSION_10:
+			xmlTextWriterWriteRaw(assm->writer, (xmlChar *)"<!DOCTYPE SyncML PUBLIC \"-//SYNCML//DTD SyncML 1.0//EN\" \"http://www.syncml.org/docs/syncml_represent_v10_20001207.dtd\">");
 			if (!_smlXmlAssemblerStartNodeNS(assm, SML_ELEMENT_SYNCML, SML_NAMESPACE_SYNCML10, error))
 				goto error_free_writer;
 			break;
 		case SML_VERSION_11:
+			xmlTextWriterWriteRaw(assm->writer, (xmlChar *)"<!DOCTYPE SyncML PUBLIC \"-//SYNCML//DTD SyncML 1.1//EN\" \"http://www.syncml.org/docs/syncml_represent_v11_20020213.dtd.dtd\">");
 			if (!_smlXmlAssemblerStartNodeNS(assm, SML_ELEMENT_SYNCML, SML_NAMESPACE_SYNCML11, error))
 				goto error_free_writer;
 			break;
 		case SML_VERSION_12:
+			xmlTextWriterWriteRaw(assm->writer, (xmlChar *)"<!DOCTYPE SyncML PUBLIC \"-//SYNCML//DTD SyncML 1.2//EN\" \"http://www.openmobilealliance.org/tech/DTD/OMA-TS-SyncML_RepPro_DTD-V1_2.dtd\">");
 			if (!_smlXmlAssemblerStartNodeNS(assm, SML_ELEMENT_SYNCML, SML_NAMESPACE_SYNCML12, error))
 				goto error_free_writer;
 			break;
@@ -1956,6 +1959,24 @@ SmlBool smlXmlDevInfAssemble(SmlDevInf *devinf, SmlDevInfVersion version, char *
 			goto error_free_buffer;
 	}
 
+	// CTCap
+	if (devinf->ctcaps) {
+		if (!_smlXmlAssemblerStartNode(assm, SML_ELEMENT_CTCAP, error))
+			goto error;
+		
+		for (d = devinf->ctcaps; d; d = d->next) {
+			SmlDevInfCTCap *ctcap = d->data;
+			const char *element_name;
+			if (!(element_name = smlDevInfCTCapTypeToString(ctcap->type, error)))
+				goto error;
+			if (!_smlXmlAssemblerAddString(assm, element_name, ctcap->value, error))
+				goto error;
+		}
+		
+		if (!_smlXmlAssemblerEndNode(assm, error))
+			goto error;
+	}
+
 	//Devinf
 	if (!_smlXmlAssemblerEndNode(assm, error))
 		goto error;
