@@ -114,7 +114,7 @@ error:
 	return NULL;	
 }
 
-void smlDevInfRef(SmlDevInf *devinf)
+SmlDevInf *smlDevInfRef(SmlDevInf *devinf)
 {
 	smlTrace(TRACE_ENTRY, "%s(%p)", __func__, devinf);
 	smlAssert(devinf);
@@ -122,6 +122,7 @@ void smlDevInfRef(SmlDevInf *devinf)
 	g_atomic_int_inc(&(devinf->refCount));
 	
 	smlTrace(TRACE_EXIT, "%s: New refcount: %i", __func__, devinf->refCount);
+	return devinf;
 }
 
 void smlDevInfUnref(SmlDevInf *devinf)
@@ -147,6 +148,13 @@ void smlDevInfUnref(SmlDevInf *devinf)
 		}
 		g_list_free(devinf->datastores);
 		
+		for (d = devinf->ctcaps; d; d = d->next) {
+			SmlDevInfCTCap *ctcap = d->data;
+			g_free(ctcap->value);
+			g_free(ctcap);
+		}
+		g_list_free(devinf->ctcaps);
+		
 		g_free(devinf);
 	}
 	
@@ -323,7 +331,7 @@ error:
 }
 
 
-void smlDevInfDataStoreRef(SmlDevInfDataStore *datastore)
+SmlDevInfDataStore *smlDevInfDataStoreRef(SmlDevInfDataStore *datastore)
 {
 	smlTrace(TRACE_ENTRY, "%s(%p)", __func__, datastore);
 	smlAssert(datastore);
@@ -331,6 +339,7 @@ void smlDevInfDataStoreRef(SmlDevInfDataStore *datastore)
 	g_atomic_int_inc(&(datastore->refCount));
 	
 	smlTrace(TRACE_EXIT, "%s: New refcount: %i", __func__, datastore->refCount);
+	return datastore;
 }
 
 void smlDevInfDataStoreUnref(SmlDevInfDataStore *datastore)
@@ -694,4 +703,94 @@ error:
 	return NULL;
 }
 
+void smlDevInfAddCTCap(SmlDevInf *devinf, SmlDevInfCTCapType type, const char *value)
+{
+	smlTrace(TRACE_ENTRY, "%s(%p, %i, %s)", __func__, devinf, type, value);
+	smlAssert(devinf);
+	smlAssert(value);
+
+	SmlDevInfCTCap *ctcap = smlTryMalloc0(sizeof(SmlDevInfCTCap), NULL);
+	if (!ctcap) {
+		return;
+	}
+
+	ctcap->type = type;
+	ctcap->value = g_strdup (value);
+
+	devinf->ctcaps = g_list_append (devinf->ctcaps, ctcap);
+
+	smlTrace(TRACE_EXIT, "%s", __func__);
+}
+
+unsigned int smlDevInfNumCTCaps(SmlDevInf *devinf)
+{
+	smlAssert(devinf);
+
+	return g_list_length(devinf->ctcaps);
+}
+
+SmlDevInfCTCapType smlDevInfGetNthCTCapType(SmlDevInf *devinf, unsigned int nth)
+{
+	smlAssert(devinf);
+
+	SmlDevInfCTCap *ctcap = g_list_nth_data(devinf->ctcaps, nth);
+	return ctcap->type;
+}
+
+const char *smlDevInfGetNthCTCapValue(SmlDevInf *devinf, unsigned int nth)
+{
+	smlAssert(devinf);
+
+	SmlDevInfCTCap *ctcap = g_list_nth_data(devinf->ctcaps, nth);
+	return ctcap->value;
+}
+
+SmlDevInfCTCapType smlDevInfCTCapTypeFromString(const char *name, SmlError **error)
+{
+	if (!strcmp(name, SML_ELEMENT_CTTYPE)) {
+		return SML_DEVINF_CTCAP_CTTYPE;
+	} else if (!strcmp(name, SML_ELEMENT_PROPNAME)) {
+		return SML_DEVINF_CTCAP_PROPNAME;
+	} else if (!strcmp(name, SML_ELEMENT_VALENUM)) {
+		return SML_DEVINF_CTCAP_VALENUM;
+	} else if (!strcmp(name, SML_ELEMENT_DATATYPE)) {
+		return SML_DEVINF_CTCAP_DATATYPE;
+	} else if (!strcmp(name, SML_ELEMENT_SIZE)) {
+		return SML_DEVINF_CTCAP_SIZE;
+	} else if (!strcmp(name, SML_ELEMENT_DISPLAYNAME)) {
+		return SML_DEVINF_CTCAP_DISPLAYNAME;
+	} else if (!strcmp(name, SML_ELEMENT_PARAMNAME)) {
+		return SML_DEVINF_CTCAP_PARAMNAME;
+	}
+	
+	smlErrorSet(error, SML_ERROR_GENERIC, "Unknown ctcap type name \"%s\"", name);
+	return SML_DEVINF_CTCAP_UNKNOWN;
+}
+
+
+const char *smlDevInfCTCapTypeToString(SmlDevInfCTCapType type, SmlError **error)
+{
+	switch (type) {
+		case SML_DEVINF_CTCAP_CTTYPE:
+			return SML_ELEMENT_CTTYPE;
+		case SML_DEVINF_CTCAP_PROPNAME:
+			return SML_ELEMENT_PROPNAME;
+		case SML_DEVINF_CTCAP_VALENUM:
+			return SML_ELEMENT_VALENUM;
+		case SML_DEVINF_CTCAP_DATATYPE:
+			return SML_ELEMENT_DATATYPE;
+		case SML_DEVINF_CTCAP_SIZE:
+			return SML_ELEMENT_SIZE;
+		case SML_DEVINF_CTCAP_DISPLAYNAME:
+			return SML_ELEMENT_DISPLAYNAME;
+		case SML_DEVINF_CTCAP_PARAMNAME:
+			return SML_ELEMENT_PARAMNAME;
+		default:
+			;
+	}
+	
+	smlErrorSet(error, SML_ERROR_GENERIC, "Unknown ctcap type \"%i\"", type);
+	return NULL;
+}
+
 /*@}*/
