@@ -287,10 +287,11 @@ static SmlAssemblerResult _smlSessionStartCommandInternal(SmlSession *session, S
 		if (!smlItemGetData(cmd->private.change.item, &data, &size, error))
 			goto error;
 		
-		/* If the size of the item is larger than the max obj size, we have to return
-		 * an error */
-		if (size > smlSessionGetSendingMaxObjSize(session)) {
-			smlErrorSet(error, SML_ERROR_SIZE_MISMATCH, "Item is larger than the limit");
+		/* If max obj size is not unlimited (0), and the size of the item is larger
+		 * than the max obj size, we have to return an error */
+		int sendingmaxobjsize = smlSessionGetSendingMaxObjSize(session);
+		if ((sendingmaxobjsize > 0) && (size > sendingmaxobjsize)) {
+			smlErrorSet(error, SML_ERROR_SIZE_MISMATCH, "Item (%ub) is larger than the limit (%db)", size, smlSessionGetSendingMaxObjSize(session));
 			goto error;
 		}
 		
@@ -834,7 +835,9 @@ parse_status:
 						smlItemRef(session->incomingBuffer);
 						smlTrace(TRACE_INTERNAL, "New Buffer started. Buffer size: %i. Required: %i", xmlBufferLength(session->incomingBuffer->buffer), session->incomingBuffer->size);
 						
-						smlTrace(TRACE_INTERNAL, "Content so far: %s\n", smlPrintBinary((char *)xmlBufferContent(session->incomingBuffer->buffer), xmlBufferLength(session->incomingBuffer->buffer)));
+						char *bin = smlPrintBinary((char *) xmlBufferContent(session->incomingBuffer->buffer), xmlBufferLength(session->incomingBuffer->buffer));
+						smlTrace(TRACE_INTERNAL, "Content so far: %s\n", bin);
+						g_free(bin);
 					}
 					
 					if (cmd->private.change.item->moreData == TRUE) {
@@ -953,7 +956,7 @@ parse_status:
 		 * next message */
 		if (smlAssemblerIsEmpty(session->assembler)) {
 			/* The assembler is empty so we need to add an alert */
-			SmlCommand *alert = smlCommandNewAlert(SML_ALERT_NEXT_MESSAGE, session->target, session->source, NULL, NULL, NULL, error);
+			SmlCommand *alert = smlCommandNewAlert(SML_ALERT_NEXT_MESSAGE, session->source, session->target, NULL, NULL, NULL, error);
 			if (!alert)
 				goto error_free_cmd;
 				
@@ -1151,7 +1154,7 @@ error:
 	return NULL;
 }
 
-void smlSessionRef(SmlSession *session)
+SmlSession *smlSessionRef(SmlSession *session)
 {
 	smlTrace(TRACE_ENTRY, "%s(%p)", __func__, session);
 	smlAssert(session);
@@ -1159,6 +1162,7 @@ void smlSessionRef(SmlSession *session)
 	g_atomic_int_inc(&(session->refCount));
 	
 	smlTrace(TRACE_EXIT, "%s: New refcount: %i", __func__, session->refCount);
+	return session;
 }
 
 void smlSessionUnref(SmlSession *session)
