@@ -448,7 +448,7 @@ static void _event_callback(SmlSession *session, SmlSessionEventType type, SmlCo
 			g_atomic_int_add(&session_ends, 1);
 			break;
 		default:
-			fail();
+			fail(NULL);
 	}
 	
 	smlTrace(TRACE_EXIT, "%s", __func__);
