@@ -133,6 +133,8 @@ START_TEST (http_server_init)
 	config.port = 32425;
 	config.url = "/test";
 	config.interface = NULL;
+	config.ssl_key = NULL;
+	config.ssl_crt = NULL;
 	
 	fail_unless(smlTransportInitialize(tsp, &config, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -157,6 +159,8 @@ START_TEST (http_server_wrong_port)
 	config.port = -1;
 	config.url = NULL;
 	config.interface = NULL;
+	config.ssl_key = NULL;
+	config.ssl_crt = NULL;
 	
 	fail_unless(!smlTransportInitialize(tsp, &config, &error), NULL);
 	fail_unless(error != NULL, NULL);
@@ -242,7 +246,7 @@ SmlBool _recv_server_event(SmlTransport *tsp, SmlLink *link, SmlTransportEventTy
 				smlTransportSetError(tsp, link, &newerror);
 				smlErrorDeref(&newerror);
 			} else
-				fail();
+				fail(NULL);
 			break;
 		default:
 			fail(NULL);
@@ -269,6 +273,8 @@ START_TEST (http_connect)
 	serverConfig.port = 10008;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -324,6 +330,8 @@ START_TEST (http_send)
 	serverConfig.port = 10009;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -378,6 +386,8 @@ START_TEST (http_receive)
 	serverConfig.port = 10010;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -438,6 +448,8 @@ START_TEST (http_reply)
 	serverConfig.port = 10011;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -501,6 +513,8 @@ START_TEST (http_talk)
 	serverConfig.port = 10012;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -617,6 +631,8 @@ START_TEST (http_reject)
 	serverConfig.port = 10014;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -684,6 +700,8 @@ START_TEST (http_multi_connect)
 	serverConfig.port = 10015;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client1, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -773,6 +791,8 @@ START_TEST (http_multi_partial_error)
 	serverConfig.port = 10016;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client1, &error), NULL);
 	fail_unless(error == NULL, NULL);
@@ -866,6 +886,8 @@ START_TEST (http_multi_stress)
 	serverConfig.port = 10017;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 
 	fail_unless(smlTransportRunAsync(client1, &error), NULL);
 	fail_unless(error == NULL, NULL);
