@@ -290,6 +290,8 @@ START_TEST (sync_multi_start)
 	serverConfig.port = 12004;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 	
 	managerTracker *clienttracker = g_malloc0(sizeof(managerTracker));
 	SmlManager *clientmanager = clienttracker->manager = smlManagerNew(client, &error);
@@ -468,6 +470,8 @@ START_TEST (sync_multi_stress)
 	serverConfig.port = 12004;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 	
 	managerTracker *clienttracker = g_malloc0(sizeof(managerTracker));
 	SmlManager *clientmanager = clienttracker->manager = smlManagerNew(client, &error);
@@ -746,6 +750,8 @@ START_TEST (sync_multi_stress2)
 	serverConfig.port = 12004;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 	
 	managerTracker *clienttracker = g_malloc0(sizeof(managerTracker));
 	SmlManager *clientmanager = clienttracker->manager = smlManagerNew(client, &error);
@@ -1100,6 +1106,8 @@ START_TEST (sync_multi_conf_from_devinf)
 	serverConfig.port = 12004;
 	serverConfig.url = NULL;
 	serverConfig.interface = NULL;
+	serverConfig.ssl_key = NULL;
+	serverConfig.ssl_crt = NULL;
 	
 	managerTracker *clienttracker = g_malloc0(sizeof(managerTracker));
 	SmlManager *clientmanager = clienttracker->manager = smlManagerNew(client, &error);
