@@ -1392,7 +1392,7 @@ START_TEST (check_assembler_stress_limit)
 			fail_unless(smlAssemblerAddStatus(assm, status, &error) == SML_ASSEMBLER_RESULT_OK);
 			fail_unless(error == NULL, NULL);
 		} else if (res != SML_ASSEMBLER_RESULT_OK)
-			fail();
+			fail(NULL);
 		
 		smlStatusUnref(status);
 	}
@@ -1421,7 +1421,7 @@ START_TEST (check_assembler_stress_limit)
 			fail_unless(smlAssemblerStartCommand(assm, NULL, cmd1, &error), NULL);
 			fail_unless(error == NULL, NULL);
 		} else if (res != SML_ASSEMBLER_RESULT_OK)
-			fail();
+			fail(NULL);
 	
 		smlCommandUnref(cmd1);
 		
