@@ -367,6 +367,8 @@ int main(int argc, char *argv[])
 	config.port = 9999;
 	config.url = NULL;
 	config.interface = NULL;
+	config.ssl_key = NULL;
+	config.ssl_crt = NULL;
 	
 	SmlError *error = NULL;
 	
@@ -559,7 +561,7 @@ int main(int argc, char *argv[])
 			printf("\n");
 			printf("ReceiveLimit: %i\n", recvLimit);
 			printf("MaxObjSize: %i\n", maxObjSize);
-			printf("Connection used: Obex\n");
+			printf("Connection used: HTTP Server\n");
 			printf("\nDatabases:\n");
 			int i = 0;
 			for (i = 0; i < g_list_length(dbLocations); i++) {
