@@ -700,7 +700,7 @@ int main(int argc, char *argv[])
 			printf("\n");
 			printf("ReceiveLimit: %i\n", recvLimit);
 			printf("MaxObjSize: %i\n", maxObjSize);
-			printf("Connection used: Obex\n");
+			printf("Connection used: OBEX Client\n");
 			printf("Identifier: %s\n", identifier);
 			printf("\nDatabases:\n");
 			int i = 0;
@@ -718,6 +718,7 @@ int main(int argc, char *argv[])
 	}
 	
 	g_free(identifier);
+	g_free(config.url);
 	
 	return 0;
 
